<?php if ( ! defined( 'FW' ) ) {
	die( 'Forbidden' );
}

class FW_Extension_SERVICES extends FW_Extension {
  private $post_type = 'ht-service';
  private $post_type_slug = 'services';
  private $taxonomy_name = 'ht-service-filter';
  private $taxonomy_slug = 'service-filter';

  public function _init(){
    $this->define_slugs();

    if ( is_admin() ) {
	  $this->add_admin_filters();
	}

    add_action( 'init', array( $this, 'consult_action_register_post_type' ) );
    add_action( 'init', array( $this, 'consult_action_register_taxonomy' ) );
  }

  private function define_slugs(){
    $this->slug = apply_filters( 'consult_service_slug', $this->post_type_slug );
    $this->taxonomy_slug = apply_filters( 'consult_service_taxonomy_slug', $this->taxonomy_slug );
  }
  public function add_admin_filters() {

	add_filter( 'fw_post_options', array( $this, '_filter_admin_add_post_options' ), 10, 2 );
}
  public function consult_action_register_post_type() {
    $post_names = apply_filters( 'fw_ext_projects_post_type_name',
			array(
				'singular' => __( 'Service', 'seocode' ),
				'plural'   => __( 'Services', 'seocode' )
			) );

		register_post_type( $this->post_type,
			array(
				'labels'             => array(
					'name'               => $post_names['plural'], //__( 'Portfolio', 'seocode' ),
					'singular_name'      => $post_names['singular'], //__( 'Portfolio project', 'seocode' ),
					'add_new'            => __( 'Add New', 'seocode' ),
					'add_new_item'       => sprintf( __( 'Add New %s', 'seocode' ), $post_names['singular'] ),
					'edit'               => __( 'Edit', 'seocode' ),
					'edit_item'          => sprintf( __( 'Edit %s', 'seocode' ), $post_names['singular'] ),
					'new_item'           => sprintf( __( 'New %s', 'seocode' ), $post_names['singular'] ),
					'all_items'          => sprintf( __( 'All %s', 'seocode' ), $post_names['plural'] ),
					'view'               => sprintf( __( 'View %s', 'seocode' ), $post_names['singular'] ),
					'view_item'          => sprintf( __( 'View %s', 'seocode' ), $post_names['singular'] ),
					'search_items'       => sprintf( __( 'Search %s', 'seocode' ), $post_names['plural'] ),
					'not_found'          => sprintf( __( 'No %s Found', 'seocode' ), $post_names['plural'] ),
					'not_found_in_trash' => sprintf( __( 'No %s Found In Trash', 'seocode' ), $post_names['plural'] ),
					'parent_item_colon'  => '' /* text for parent types */
				),
				'description'        => __( 'Create a service item', 'seocode' ),
				'public'             => true,
				'show_ui'            => true,
				'show_in_menu'       => true,
				'show_in_nav_menus' 	=> true,
				'publicly_queryable' => true,
				/* queries can be performed on the front end */
				'has_archive'        => true,
				'rewrite'            => array(
					'slug' => $this->slug
				),
				'menu_position'      => 4,
				'show_in_nav_menus'  => true,
				'menu_icon'          => 'dashicons-clipboard',
				'hierarchical'       => false,
				'query_var'          => true,
				/* Sets the query_var key for this post type. Default: true - set to $post_type */
				'supports'           => array(
					'title', /* Text input field to create a post title. */
					'editor',
					'thumbnail', /* Displays a box for featured image. */
					'excerpt'
				),
				'capabilities'       => array(
					'edit_post'              => 'edit_pages',
					'read_post'              => 'edit_pages',
					'delete_post'            => 'edit_pages',
					'edit_posts'             => 'edit_pages',
					'edit_others_posts'      => 'edit_pages',
					'publish_posts'          => 'edit_pages',
					'read_private_posts'     => 'edit_pages',
					'read'                   => 'edit_pages',
					'delete_posts'           => 'edit_pages',
					'delete_private_posts'   => 'edit_pages',
					'delete_published_posts' => 'edit_pages',
					'delete_others_posts'    => 'edit_pages',
					'edit_private_posts'     => 'edit_pages',
					'edit_published_posts'   => 'edit_pages',
				),
			) );
  }

  public function consult_action_register_taxonomy() {
    $category_names = apply_filters( 'fw_ext_portfolio_category_name', array(
			'singular' => __( 'Category', 'seocode' ),
			'plural'   => __( 'Categories', 'seocode' )
		) );

		register_taxonomy( $this->taxonomy_name, $this->post_type, array(
			'labels'            => array(
				'name'              => sprintf( _x( 'Service %s', 'taxonomy general name', 'seocode' ), $category_names['plural'] ),
				'singular_name'     => sprintf( _x( 'Service %s', 'taxonomy singular name', 'seocode' ), $category_names['singular'] ),
				'search_items'      => sprintf( __( 'Search %s', 'seocode' ), $category_names['plural'] ),
				'all_items'         => sprintf( __( 'All %s', 'seocode' ), $category_names['plural'] ),
				'parent_item'       => sprintf( __( 'Parent %s', 'seocode' ), $category_names['singular'] ),
				'parent_item_colon' => sprintf( __( 'Parent %s:', 'seocode' ), $category_names['singular'] ),
				'edit_item'         => sprintf( __( 'Edit %s', 'seocode' ), $category_names['singular'] ),
				'update_item'       => sprintf( __( 'Update %s', 'seocode' ), $category_names['singular'] ),
				'add_new_item'      => sprintf( __( 'Add New %s', 'seocode' ), $category_names['singular'] ),
				'new_item_name'     => sprintf( __( 'New %s Name', 'seocode' ), $category_names['singular'] ),
				'menu_name'         => $category_names['plural'],
			),
			'public'            => true,
			'hierarchical'      => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'query_var'         => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => false,
			'rewrite'           => array(
				'slug' => $this->taxonomy_slug
			),
		) );
  }

  /**
	 * @internal
	 *
	 * @param array $options
	 * @param string $post_type
	 *
	 * @return array
	 */
	public function _filter_admin_add_post_options( $options, $post_type ) {
		if ( $post_type === $this->post_type ) {
			$options[] = array(
				$this->get_options('posts/'.$post_type, $options = array())
			);
		}


		return $options;
	}

	public function get_post_type_name() {
		return $this->post_type;
	}

	public function get_taxonomy_name() {
		return $this->taxonomy_name;
	}
}
