<?php

/* Helper functions and classes with static methods for usage in theme */

/*Register Lato Google font*/
if(!function_exists('seocode_font_url')){
	function seocode_font_url() {
		$fonts_url = '';
		/* Translators: If there are characters in your language that are not
	    * supported by Lato, translate this to 'off'. Do not translate
	    * into your own language.
	    */
		$lato = esc_html_x( 'on', 'Lato font: on or off', 'seocode');

		/* Translators: If there are characters in your language that are not
	    * supported by Open Sans, translate this to 'off'. Do not translate
	    * into your own language.
	    */
		$montserrat = esc_html_x( 'on', 'Montserrat font: on or off', 'seocode');

		if (  'off' !== $lato || 'off' !== $montserrat) {
			$font_families = array();

			if ( 'off' !== $lato ) {
				$font_families[] = 'Lato:700,400,800,600,300';
			}

			if ( 'off' !== $montserrat ) {
				$font_families[] = 'Montserrat:700,400,800,600';
			}

			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
		}

		return esc_url_raw( $fonts_url );
	}
}

/*replace more excerpt text*/
function seocode_replace_excerpt( $more ) {
	return '...';
}
add_filter( 'excerpt_more', 'seocode_replace_excerpt' );

if ( ! function_exists('seocode_the_attached_image') ) : /**
 * Print the attached image with a link to the next attached image.
 */ {
	function seocode_the_attached_image() {
		$post = get_post();
		/**
		 * Filter the default attachment size.
		 *
		 * @param array $dimensions {
		 *     An array of height and width dimensions.
		 *
		 * @type int $height Height of the image in pixels. Default 810.
		 * @type int $width Width of the image in pixels. Default 810.
		 * }
		 */
		$attachment_size     = apply_filters( 'seocode_attachment_size', array( 810, 810 ) );
		$next_attachment_url = wp_get_attachment_url();

		/*
		 * Grab the IDs of all the image attachments in a gallery so we can get the URL
		 * of the next adjacent image in a gallery, or the first image (if we're
		 * looking at the last image in a gallery), or, in a gallery of one, just the
		 * link to that image file.
		 */
		$attachment_ids = get_posts( array(
			'post_parent'    => $post->post_parent,
			'fields'         => 'ids',
			'numberposts'    => - 1,
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => 'ASC',
			'orderby'        => 'menu_order ID',
		) );

		// If there is more than 1 attachment in a gallery...
		if ( count( $attachment_ids ) > 1 ) {
			foreach ( $attachment_ids as $attachment_id ) {
				if ( $attachment_id == $post->ID ) {
					$next_id = current( $attachment_ids );
					break;
				}
			}

			// get the URL of the next image attachment...
			if ( $next_id ) {
				$next_attachment_url = get_attachment_link( $next_id );
			} // or get the URL of the first image attachment.
			else {
				$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
			}
		}

		printf( '<a href="%1$s" rel="attachment">%2$s</a>',
			esc_url( $next_attachment_url ),
			wp_get_attachment_image( $post->ID, $attachment_size )
		);
	}
}
endif;

/* Custom template tags */
{
	/* Filter function to be used with number_format_i18n filter hook */
    if( ! function_exists( 'seocode_paging_zero_prefix' ) ) :
		function seocode_paging_zero_prefix( $format ) {
			$number = intval( $format );
			if( intval( $number / 10 ) > 0 ) {
				return $format;
			}
			return '0' . $format;
		}
    endif;
	/*blog pagination*/
	if ( ! function_exists( 'seocode_paging_nav' ) ) :
		function seocode_paging_nav( $wp_query = null ) {

			if ( ! $wp_query ) {
				$wp_query = $GLOBALS['wp_query'];
			}

			/*Don't print empty markup if there's only one page.*/

			if ( $wp_query->max_num_pages < 2 ) {
				return;
			}

			$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
			$pagenum_link = html_entity_decode( get_pagenum_link() );
			$query_args   = array();
			$url_parts    = explode( '?', $pagenum_link );

			if ( isset( $url_parts[1] ) ) {
				wp_parse_str( $url_parts[1], $query_args );
			}

			add_filter( 'number_format_i18n', 'seocode_paging_zero_prefix' );

			$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
			$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

			$format = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link,
				'index.php' ) ? 'index.php/' : '';
			$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%',
				'paged' ) : '?paged=%#%';

			/*Set up paginated links.*/
			$links = paginate_links( array(
				'base'      => $pagenum_link,
				'format'    => $format,
				'total'     => $wp_query->max_num_pages,
				'current'   => $paged,
				'mid_size'  => 1,
				'after_page_number' => '.',
				'add_args'  => array_map( 'urlencode', $query_args ),
				'prev_text' => '',
				'next_text' => '',
				'type' 		=> 'list'
			) );

			remove_filter( 'number_format_i18n', 'seocode_paging_zero_prefix' );

			if ( $links ) :

				?>
				<nav class="paging-navigation" role="navigation">
					<h1 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'seocode'); ?></h1>
						<?php echo wp_kses($links,
						array(
							'ul' => array(
								'class' => array(),
							),
							'li' => array(),
							'span' => array(
								'class' => array(),
							),
							'a' => array(
								'class' => array(),
								'href' => array(),
							),
						)); ?>
				</nav>
			<?php
			endif;
		}
	endif;
	/*post date*/
	if ( ! function_exists( 'seocode_post_date' ) ) :
		function seocode_post_date() {
			$post_date = get_the_date('d');
			$post_m = get_the_date('M');
			$post_y = get_the_date('Y');

			$post_info = '<span class="date-day">'.$post_date.'</span>';
			$post_info .= '<span class="date-month">'.$post_m.'</span>';
			$post_info .= '<span class="date-year">'.$post_y.'</span>';

			return $post_info;
		}
	endif;
	/*blog categories*/
	if(!function_exists('seocode_blog_categories')):
		function seocode_blog_categories(){
			$categories_string = '';
			$categories = get_the_category();
			$separator = ', ';
			$output = '';
			if ( ! empty( $categories ) ) {
				foreach( $categories as $category ) {
					$output .= '<a href="' . esc_url( get_category_link( $category->term_id ) ) . '" title="' . esc_attr( sprintf( esc_html__( 'View all posts in %s', 'seocode'), $category->name ) ) . '">' . esc_html( $category->name ) . '</a>' . $separator;
				}
				$categories_string .= trim( $output, $separator );
			}
			return $categories_string;
		}
	endif;
	/*custom excerpt*/
	if( ! function_exists('seocode_excerpt')):
		function seocode_excerpt($limit) {
			$excerpt = explode(' ', get_the_excerpt(), $limit);
			if (count($excerpt)>=$limit) {
				array_pop($excerpt);
				$excerpt = implode(" ",$excerpt).'...';
			} else {
				$excerpt = implode(" ",$excerpt);
			} 
			$excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
			return $excerpt;
		}
	endif;
	/*post navigation*/
	if ( ! function_exists('seocode_theme_post_nav') ) :
		function seocode_theme_post_nav() {
			// Don't print empty markup if there's nowhere to navigate.
			$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
			$next     = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous ) {
				return;
			}
			if(!empty($previous)){
				$pre_link = get_permalink($previous);
				$pre_post_id = $previous->ID;
				$pre_post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($pre_post_id), 'thumbnail' );
			}
			if(!empty($next)){
				$next_link = get_permalink($next);
				$next_post_id = $next->ID;
				$next_post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($next_post_id), 'thumbnail' );
			}

			?>

			<div class="blog-related-post flw">
				<?php
				if( is_attachment() ):
				?>
				<?php if(!empty($previous)){ ?>
					<div class="prev-post">
						<?php if($pre_post_thumb != false) : ?>
							<div class="control-post-img">
								<img src="<?php echo esc_url($pre_post_thumb[0]); ?>"
									 alt="<?php esc_attr_e('Post nav thumb', 'seocode'); ?>">
							</div>
						<?php endif; ?>
						<div class="control-post-desc">
							<h3 class="control-post-name"><?php previous_post_link('%link'); ?></h3>
							<a href="<?php echo esc_url($pre_link); ?>" class="control-post-btn"><?php esc_html_e('Previous', 'seocode'); ?></a>
						</div>
					</div>
				<?php } ?>
				<?php else : ?>
				<?php if(!empty($previous)){ ?>
					<div class="prev-post">
						<?php if($pre_post_thumb != false) : ?>
							<div class="control-post-img">
								<img src="<?php echo esc_url($pre_post_thumb[0]); ?>"
									 alt="<?php esc_attr_e('Post nav thumb', 'seocode'); ?>">
							</div>
						<?php endif; ?>
						<div class="control-post-desc">
							<h3 class="control-post-name"><?php previous_post_link('%link'); ?></h3>
							<a href="<?php echo esc_url($pre_link); ?>" class="control-post-btn"><?php esc_html_e('Previous', 'seocode'); ?></a>
						</div>
					</div>
				<?php } ?>
				<?php if(!empty($next)){ ?>
					<div class="next-post">
						<?php if($next_post_thumb != false) : ?>
							<div class="control-post-img">
								<img src="<?php echo esc_url($next_post_thumb[0]); ?>"
									 alt="<?php esc_attr_e('Post nav thumb', 'seocode'); ?>">
							</div>
						<?php endif; ?>
						<div class="control-post-desc">
							<h3 class="control-post-name"><?php next_post_link('%link'); ?></h3>
							<a href="<?php echo esc_url($next_link); ?>" class="control-post-btn"><?php esc_html_e('Next', 'seocode'); ?></a>
						</div>
					</div>
				<?php } ?>
				<?php endif; ?>
			</div>
			<?php
		}
	endif;
	/**
	 * Find out if blog has more than one category.
	 * @return boolean true if blog has more than 1 category
	 */
	function seocode_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'seocode_category_count' ) ) ) {
			// Create an array of all the categories that are attached to posts
			$all_the_cool_cats = get_categories( array(
				'hide_empty' => 1,
			) );

			// Count the number of categories that are attached to the posts
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'seocode_category_count', $all_the_cool_cats );
		}

		if ( 1 !== (int) $all_the_cool_cats ) {
			// This blog has more than 1 category so seocode_categorized_blog should return true
			return true;
		} else {
			// This blog has only 1 category so seocode_categorized_blog should return false
			return false;
		}
	}

}

/*theme suopprt*/
function seocode_theme_support() {
    add_theme_support( 'woocommerce' );
    add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'seocode_theme_support' );


/*call shopping cart*/
function seocode_shopping_cart(){
    if(class_exists('Woocommerce')):
	global $woocommerce;
	$total_item = $woocommerce->cart->cart_contents_count; ?>
		<div class="theme-shoping-cart">
			<a class="fa fa-shopping-bag shopping-cart-icon" href="<?php echo wc_get_cart_url(); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'seocode' ); ?>">
				<?php if($total_item > 0): ?>
					<span class="counter-cart"><?php echo esc_html($total_item); ?></span>
				<?php endif; ?>
			</a>
			<?php if($total_item > 0): ?>
				<div class="theme-minicart">
					<?php woocommerce_mini_cart(); ?>
				</div>
			<?php endif; ?>
		</div>
	<?php endif;
}

/*shopping cart - total item*/
add_filter('add_to_cart_fragments', function( $fragments ) {
	global $woocommerce;
	$total_item = $woocommerce->cart->cart_contents_count;
	ob_start(); ?>
	<span class="counter-cart"><?php echo esc_html($total_item); ?></span>
	<?php $fragments['span.counter-cart'] = ob_get_clean();	
	return $fragments;
});

/*shopping cart - mini cart*/
add_filter( 'add_to_cart_fragments', function($fragments) {
	global $woocommerce;
	$total_item = $woocommerce->cart->cart_contents_count;
    ob_start(); ?>
		<div class="theme-minicart">
			<?php woocommerce_mini_cart(); ?>
		</div>
	<?php
	$fragments['div.theme-minicart'] = ob_get_clean();
    return $fragments;

} );


/*Custom comment output*/
function seocode_comment_list($comment, $args, $depth){
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
		<div class="comment-post-pingback">
			<?php esc_html_e( 'Pingback:', 'seocode' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'seocode' ), '<span class="edit-link">', '</span>' ); ?>
		</div>
	<?php
		break;
		default :
	?>
	<div id="comment-<?php comment_ID(); ?>" class="comment-item" itemscope itemtype="http://schema.org/Comment">
		<div class="comment-avatar">
			<?php echo get_avatar($comment,$size='60'); ?>
		</div>
		<div class="comment-content">
			<a href="#comment-<?php comment_ID(); ?>" itemprop="discussionUrl"><strong class="comment-author-name" itemprop="creator"><?php echo get_comment_author(); ?></strong></a>
			<div class="comment-time" itemprop="datePublished" content="<?php echo get_the_time('c'); ?>"><?php echo get_comment_date("Y-m-d g:i a"); ?></div>
			<div class="comment-text" itemprop="about">
				<?php if ($comment->comment_approved == '0') : ?>
					<em><?php esc_html_e('Your comment is awaiting moderation.', 'seocode') ?></em>
				<?php endif; ?>
				<?php comment_text() ?>
			</div>
			<?php edit_comment_link(esc_html__('Edit', 'seocode'), '  ', '') ?>
			<?php echo get_comment_reply_link(array_merge($args,array(
				'depth' => $depth,
				'reply_text' => 'Reply',
				'max_depth' => $args['max_depth'])));
			?>
		</div>
	</div>
<?php
	break;
	endswitch;
}

/*Author Card*/
if(!function_exists('seocode_author_card')){
	function seocode_author_card(){
		if ( empty( $post ) && isset( $GLOBALS['post'] ) )
		$post = $GLOBALS['post'];
		$authordesc = get_the_author_meta( 'description' );
		if(!empty($authordesc)): ?>
			<div class="flw" itemscope itemtype="https://schema.org/CreativeWork">
				<div class="post-author-info-single" itemprop="author" itemscope itemtype="http://schema.org/Person">
					<div class="author-av"><?php echo get_avatar( $post->ID, $size = 123 ); ?></div>
					<div class="post-author-detail">
						<strong class="author-name" itemprop="name"><?php the_author(); ?></strong>
						<p class="author-desc" itemprop="description"><?php the_author_meta('description'); ?></p>
					</div>
				</div>
			</div><?php
		endif;
	}
}

/*remove query strings*/
function seocode_remove_script_version( $src ){
	$parts = explode( '?ver', $src );
	return $parts[0];
}
add_filter( 'script_loader_src', 'seocode_remove_script_version', 15, 1 );
add_filter( 'style_loader_src', 'seocode_remove_script_version', 15, 1 );

/*defer js file*/
if (!(is_admin() )) {
	function seocode_defer_parsing_of_js ( $url ) {
		if ( FALSE === strpos( $url, '.js' ) ) return $url;
        if ( strpos( $url, 'jquery.js' ) ) return $url;
		return "$url' defer='defer";
	}
	add_filter( 'clean_url', 'seocode_defer_parsing_of_js', 11, 1 );
}

/*disable font awesome unyson - front-end*/
function seocode_dequeue_fontawesome_css() {
	wp_dequeue_style('fw-font-awesome');
	wp_deregister_style('fw-ext-builder-frontend-grid');
	wp_dequeue_style('fw-ext-forms-default-styles');
	wp_deregister_style('fw-font-awesome');
}
add_action('wp_enqueue_scripts','seocode_dequeue_fontawesome_css', 100);



/*heard of WordPress*/
if ( ! isset( $content_width ) ) $content_width = 1145;


/*remove css of contact form 7*/
add_filter( 'wpcf7_load_css', '__return_false' );


/* THEME CONFIG *******************************************************************/

/* header layout */
if(!function_exists('seocode_header_layout')){
	function seocode_header_layout(){
		/*PAGE OPTIONS*/
		$pid = get_queried_object_id();
		$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : '';
		
		/*CUSTOMIZER*/
		$c_header_layout = get_theme_mod('header_layout_cfg', 'layout-1');

		if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] != 'default' ){
			switch($p_header_layout['gadget']){
				case 'layout-1' :
					get_template_part('page-templates/header', 'layout-1');
					break;
				case 'layout-2' :
					get_template_part('page-templates/header', 'layout-2');
					break;
				case 'layout-3' :
					get_template_part('page-templates/header', 'layout-3');
					break;
				case 'layout-4' :
					get_template_part('page-templates/header', 'layout-4');
					break;
			}
		}else{
			switch($c_header_layout){
				case 'layout-1' :
					get_template_part('page-templates/header', 'layout-1');
					break;
				case 'layout-2' :
					get_template_part('page-templates/header', 'layout-2');
					break;
				case 'layout-3' :
					get_template_part('page-templates/header', 'layout-3');
					break;
				case 'layout-4' :
					get_template_part('page-templates/header', 'layout-4');
					break;
				default :
					get_template_part('page-templates/header', 'layout-1');
					break;
			}
		}
	}
}

/*header layout 2 custom css - KIRKI INLINE CSS*/
add_action( 'wp_enqueue_scripts', function() {
	/*page option*/
	$pid = get_queried_object_id();
	$page_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : '';

	$custom_css = '';
	if(isset($page_header_layout['gadget']) && $page_header_layout['gadget'] == 'layout-2'){
		/*topbar text color*/
		if(!empty($page_header_layout['layout-2']['layout-2-topbar-txt-color'])){
			$custom_css .= '.page-id-' . $pid . ' .header-layout-2 .theme-header .topbar-left, .page-id-' . $pid . ' .header-layout-2 .theme-header .topbar-right{color: ' . $page_header_layout['layout-2']['layout-2-topbar-txt-color'] . '}';
		}
		/*heading menu text color*/
		if(!empty($page_header_layout['layout-2']['layout-2-menu-txt-color'])){
			$custom_css .= '.page-id-' . $pid . ' .header-layout-2 .theme-primary-menu > li > a, .page-id-' . $pid . ' .header-layout-2 #ht-btn-search, .page-id-' . $pid . ' .header-layout-2 .theme-wrap-menu-flex .collapse-button{color: ' . $page_header_layout['layout-2']['layout-2-menu-txt-color'] . '}';
		}
		/*button background*/
		if(!empty($page_header_layout['layout-2']['layout-2-btn-bg'])){
			$custom_css .= '.page-id-' . $pid . ' .theme-topbar .topbar-right .topbar-btn{background: ' . $page_header_layout['layout-2']['layout-2-btn-bg'] . '}';
		}
		/*button text color*/
		if(!empty($page_header_layout['layout-2']['layout-2-btn-color'])){
			$custom_css .= '.page-id-' . $pid . ' .theme-topbar .topbar-right .topbar-btn{color: ' . $page_header_layout['layout-2']['layout-2-btn-color'] . '}';
		}
	}
	wp_add_inline_style( "kirki-styles-seocode", $custom_css );
}, 1000 );

/*logo*/
if(!function_exists('seocode_logo_image')){
	function seocode_logo_image(){
		$pid = get_queried_object_id();
		$p_lg = function_exists('fw_get_db_post_option') ? fw_get_db_post_option($pid, 'p_lg') : '';
		
		$c_lg = get_theme_mod('logo_img', '');
		$lg_img = '';

		$tag = 'div';
		if( is_front_page() ){
			$tag = 'h1';
		}
		
		
		if(isset($p_lg['gadget']) && $p_lg['gadget'] == 'custom'){
			$lg_img = $p_lg['custom']['lg_data']['url'];
		?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
	                <img
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'seocode'); ?>"
	                	itemprop="logo"
	                	width="161"
	                	height="43" >
	            </a>
	            <span class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></span>
            </<?php echo esc_attr($tag); ?>>
        <?php }else{ $lg_img = ($c_lg != '') ? $c_lg : get_template_directory_uri().'/images/lg.png'; ?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<a class="lg" href="<?php echo esc_url(home_url("/")); ?>" itemprop="url">
	                <img
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'seocode'); ?>"
	                	itemprop="logo"
	                	width="161"
	                	height="43" >
	            </a>
	            <span class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></span>
			</<?php echo esc_attr($tag); ?>>
		<?php
		}
	}
}

/*logo sticky*/
if(!function_exists('seocode_sticky_logo_image')){
	function seocode_sticky_logo_image(){		
		$c_lg = get_theme_mod('logo_img', '');
		$lg_img = '';

		$tag = 'div';
		if( is_front_page() ){
			$tag = 'h1';
		}

		$lg_img = ($c_lg != '') ? $c_lg : get_template_directory_uri().'/images/lg.png'; ?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<a class="lg" href="<?php echo esc_url(home_url("/")); ?>" itemprop="url">
	                <img
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'seocode'); ?>"
	                	itemprop="logo"
	                	width="161"
	                	height="43" >
	            </a>
	            <span class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></span>
			</<?php echo esc_attr($tag); ?>>
		<?php
	}
}

/*footer background*/
add_action( 'wp_enqueue_scripts', function() {

	$custom_css = '';
	$c_footer_bg = get_theme_mod( 'c_footer_bg' , 'ft_color' );
	$ft_bg_img = get_theme_mod( 'ft_bg_img' , false );

	if($c_footer_bg != 'ft_color' && $ft_bg_img != ''){
		$custom_css = '.seocode-footer{background-image: url(' . esc_url($ft_bg_img) . ')}';
	}
	wp_add_inline_style( "kirki-styles-seocode", $custom_css );
}, 1001 );

/*footer widget*/
if(!function_exists('seocode_footer_sidebar')){
	function seocode_footer_sidebar(){
		if(is_active_sidebar('footer-theme-widget')): ?>
			<div class="theme-footer-widget flw">
				<div class="container">
					<div class="row">
						<?php dynamic_sidebar('footer-theme-widget'); ?>
					</div>
				</div>
			</div>
		<?php endif;
	}
}
/*footer display*/
if(!function_exists('seocode_footer_display')){
	function seocode_footer_display(){
		/*page id*/
		$pid = get_queried_object_id();
		$footer_data = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'footer_data') : '';
		$c_footer_display = get_theme_mod('c_footer_display', '1');
		
		if(isset($footer_data) && $footer_data != 'default'){
			switch($footer_data){
				case 'enable' :
					seocode_footer_sidebar();
					break;
				case 'disable' :
					break;
				}
		}else{
			switch($c_footer_display){
				case '1' :
				seocode_footer_sidebar();
					break;
				case '0' :
					break;
				default :
					seocode_footer_sidebar();
					break;
				}
		}
	}
}

/* VISUAL COMPOSER *******************************************************************/


/*Extend VC*/
if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
	function seocode_require_VC() {
		require_once get_template_directory() . '/inc/vc-include.php';
	}
	add_action( 'init', 'seocode_require_VC', 2 );
}

/*header search form*/
if(!function_exists('seocode_search_form')){
	function seocode_search_form(){ ?>
		<div class="search-viewbox" itemscope itemtype="http://schema.org/WebSite">
			<button id="ht-btn-close" class="ion-close"></button>
			<link itemprop="url" href="<?php echo esc_url(home_url('/')); ?>" />
			<form class="ht-search-form" action="<?php echo esc_url(home_url('/')); ?>" role="search" itemprop="potentialAction" itemscope itemtype="http://schema.org/SearchAction">
				<meta itemprop="target" content="<?php echo esc_url( home_url() ); ?>/?s={s}" />
				<input itemprop="query-input" id="ht-search-input" name="s" type="text" placeholder="<?php esc_attr_e('type...', 'seocode'); ?>" />
				<span class="search-info"><?php esc_html_e('Hit enter to search or ESC to close', 'seocode'); ?></span>
			</form>
		</div><?php
	}
}


/* Edit location *******************************************************************/
/*hader layout edit*/
if(!function_exists('seocode_header_edit_location')){
	function seocode_header_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()):
			echo '<div id="'. esc_attr($id) .'-edit-location" class="header-edit-location">';
				if ( class_exists( 'Kirki' ) ){
					echo Kirki::get_option($option);
				}
			echo '</div>';
		endif;
	}
}

/*breadcrumbs layout edit location*/
if(!function_exists('seocode_bread_edit_location')){
	function seocode_bread_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()):
			echo '<div id="' . esc_attr($id) . '-edit-location">';
				if ( class_exists( 'Kirki' ) ){
					echo Kirki::get_option($option);
				}
			echo '</div>';
		endif;
	}
}

/*footer layout edit location*/
if(!function_exists('seocode_footer_edit_location')){
	function seocode_footer_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()): ?>
			<div id="<?php echo esc_attr($id); ?>-edit-location">
				<?php
					if ( class_exists( 'Kirki' ) ){
						echo Kirki::get_option($option);
					}
				?>
			</div>
		<?php endif;
	}
}